vreg
====

.. image:: https://img.shields.io/badge/License-Apache_2.0-blue.svg
  :target: https://opensource.org/licenses/Apache-2.0



Numpy arrays with spatial awareness
-----------------------------------

- **Documentation:** https://openmiblab.github.io/vreg/
- **Source code:** https://github.com/openmiblab/vreg


Installation
------------

.. code-block:: console

    pip install vreg


If you want to use the optional plot module, then install as:

.. code-block:: console

    pip install vreg[plot]


License
-------

Released under the `Apache 2.0 <https://opensource.org/licenses/Apache-2.0>`_  
license::

  Copyright (C) 2024-2025 vreg developers
